@@ -1,7 +1,20 @@
-## ---- echo=FALSE--------------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
+suggested_dependent_pkgs <- c("dplyr")
+knitr::opts_chunk$set(
+  collapse = TRUE,
+  comment = "#>",
+  eval = all(vapply(
+    suggested_dependent_pkgs,
+    requireNamespace,
+    logical(1),
+    quietly = TRUE
+  ))
+)
+
+## ----echo=FALSE---------------------------------------------------------------
 knitr::opts_chunk$set(comment = "#")
 
-## ---- message=FALSE-----------------------------------------------------------
+## ----message=FALSE------------------------------------------------------------
 library(rtables)
 library(tibble)
 library(dplyr)
@@ -77,7 +90,7 @@ summary_tbl2
 ## -----------------------------------------------------------------------------
 identical(summary_tbl, summary_tbl2)
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 stopifnot(identical(summary_tbl, summary_tbl2))
 
 ## -----------------------------------------------------------------------------
@@ -96,7 +109,7 @@ lyt <- basic_table(show_colcounts = TRUE) %>%
 tbl <- build_table(lyt, ADSL)
 tbl
 
-## ---- warning=FALSE-----------------------------------------------------------
+## ----warning=FALSE------------------------------------------------------------
 lyt <- basic_table(show_colcounts = TRUE) %>%
   split_cols_by(var = "ARM") %>%
   split_rows_by("SEX") %>%
@@ -105,7 +118,7 @@ lyt <- basic_table(show_colcounts = TRUE) %>%
 tbl <- build_table(lyt, ADSL)
 tbl
 
-## ---- warning=FALSE-----------------------------------------------------------
+## ----warning=FALSE------------------------------------------------------------
 ADSL_M_F <- filter(ADSL, SEX %in% c("M", "F"))
 
 lyt2 <- basic_table(show_colcounts = TRUE) %>%
@@ -541,7 +554,7 @@ rsp_lyt3 <- basic_table(show_colcounts = TRUE) %>%
   ) %>%
   split_rows_by(
     var = "AVALC",
-    split_fun = reorder_split_levels(neworder = c("CR", "PR", "SD", "NON CR/PD", "PD", "NE"), drlevels = TRUE),
+    split_fun = reorder_split_levels(neworder = c("CR", "PR", "SD", "PD", "NE"), drlevels = TRUE),
     nested = FALSE
   ) %>%
   summarize_row_groups() %>%
